﻿Imports System.Collections.ObjectModel
Imports System.ComponentModel
Imports Infragistics.Controls.Schedules


Public Class MyViewModel
  Implements INotifyPropertyChanged

  Public Event PropertyChanged As PropertyChangedEventHandler Implements INotifyPropertyChanged.PropertyChanged

  Public Sub New()
    Init()
    CreateResources()
  End Sub
  Private Sub Init()

    With ListScheduleDataConnector
      .ResourcePropertyMappings = New ResourcePropertyMappingCollection()
      .ResourceCalendarPropertyMappings = New ResourceCalendarPropertyMappingCollection()
      .AppointmentPropertyMappings = New AppointmentPropertyMappingCollection()
      .RecurringAppointmentPropertyMappings = New AppointmentPropertyMappingCollection()

      .ResourceItemsSource = Me.Resources
      .ResourceCalendarItemsSource = Me.ResourceCalendars
      .AppointmentItemsSource = Me.Appointments
      '   .RecurringAppointmentItemsSource = Me.RecurringAppointments
      .ActivityCategoryItemsSource = Me.ActivityCategories

    End With
    DataManager.DataConnector = ListScheduleDataConnector
    DataManager.DialogFactory = New MyScheduleDialogFactory
    '  DataManager.DialogFactory = New Infragistics.Controls.Schedules.ScheduleDialogFactory

    Dim sSettings As ScheduleSettings = New ScheduleSettings()
    sSettings.AllowCustomizedCategories = True
    sSettings.AppointmentSettings = New AppointmentSettings
    sSettings.AppointmentSettings.AllowTimeZoneNeutral = True
    sSettings.AppointmentSettings.IsAddViaClickToAddEnabled = True
    'sSettings.AppointmentSettings.AllowTimeZoneNeutr = True
    Me.DataManager.Settings = sSettings

  End Sub

  Public Property Resources As ObservableCollection(Of Resource)
    Get
      If IsNothing(_resources) Then
        _resources = New ObservableCollection(Of Resource)
      End If
      Return _resources
    End Get
    Set(value As ObservableCollection(Of Resource))
      If _resources Is value Then Return
      _resources = value
      RaisePropertyChanged("Resources")
    End Set
  End Property
  Private _resources As ObservableCollection(Of Resource)

  Public Property ResourceCalendars As ObservableCollection(Of ResourceCalendar)
    Get
      If IsNothing(_resourceCalendars) Then
        _resourceCalendars = New ObservableCollection(Of ResourceCalendar)
      End If
      Return _resourceCalendars
    End Get
    Set(value As ObservableCollection(Of ResourceCalendar))
      If _resourceCalendars Is value Then Return
      _resourceCalendars = value
      RaisePropertyChanged("ResourceCalendars")
    End Set
  End Property
  Private _resourceCalendars As ObservableCollection(Of ResourceCalendar)

  Public Property ActivityCategories As ObservableCollection(Of ActivityCategory)
    Get
      If IsNothing(_activityCategories) Then
        _activityCategories = New ObservableCollection(Of ActivityCategory)
        Dim ac = New ActivityCategory
        ac.CategoryName = "test"
        ac.Color = SystemColors.ControlColor
        _activityCategories.Add(ac)
      End If
      Return _activityCategories
    End Get
    Set(value As ObservableCollection(Of ActivityCategory))

    End Set
  End Property
  Private _activityCategories As ObservableCollection(Of ActivityCategory)

  Public ReadOnly Property DataManager As XamScheduleDataManager
    Get
      If IsNothing(_datamanager) Then
        _datamanager = New XamScheduleDataManager
        'AddHandler _datamanager.ActivityAdded, AddressOf ActivityAdded
        'AddHandler _datamanager.ActivityChanged, AddressOf ActivityChanged
        'AddHandler _datamanager.ActivityRemoved, AddressOf ActivityRemoved
      End If
      Return _datamanager
    End Get
  End Property
  Private _datamanager As XamScheduleDataManager

  Public Property ListScheduleDataConnector As Infragistics.Controls.Schedules.ListScheduleDataConnector
    Get
      If IsNothing(_listScheduleDataConnector) Then
        _listScheduleDataConnector = New Infragistics.Controls.Schedules.ListScheduleDataConnector
      End If
      Return _listScheduleDataConnector
    End Get
    Set(value As Infragistics.Controls.Schedules.ListScheduleDataConnector)
      If _listScheduleDataConnector Is value Then Return
      _listScheduleDataConnector = value
      RaisePropertyChanged("ListScheduleDataConnector")
    End Set
  End Property
  Private _listScheduleDataConnector As Infragistics.Controls.Schedules.ListScheduleDataConnector

  Public Property Appointments As ObservableCollection(Of Appointment)
    Get
      If IsNothing(_appointments) Then
        _appointments = New ObservableCollection(Of Appointment)
      End If
      Return _appointments
    End Get
    Set(value As ObservableCollection(Of Appointment))
      If _appointments Is value Then Return
      _appointments = value
      RaisePropertyChanged("Appointments")
    End Set
  End Property
  Private _appointments As ObservableCollection(Of Appointment)


  Protected Overridable Sub RaisePropertyChanged(ByVal propertyName As String)
    RaiseEvent PropertyChanged(Me, New PropertyChangedEventArgs(propertyName))
  End Sub

  Private Sub CreateResources()

    Dim res1 = New Resource
    With res1
      .Id = "Res1"
      .Name = "ErsteResource"
    End With
    Me.Resources.Add(res1)

    Dim res2 = New Resource
    With res2
      .Id = "Res2"
      .Name = "ZweiteResource"
    End With
    Me.Resources.Add(res2)


    Dim resCal1 = New ResourceCalendar
    With resCal1
      .Id = "Cal1"
      .Name = "ErsterKalender"
      .OwningResourceId = "Res1"
    End With
    Me.ResourceCalendars.Add(resCal1)


    Dim resCal2 = New ResourceCalendar
    With resCal2
      .Id = "Cal2"
      .Name = "Zweiterkalender"
      .OwningResourceId = "Res2"
    End With
    Me.ResourceCalendars.Add(resCal2)

    Me.DataManager.CurrentUserId = res1.Id


    Dim res = DataManager.ResourceItems.GetResourceFromId("Res1")
    Dim cal = res.Calendars.FirstOrDefault(Function(c)
                                             Return c.Id = "Cal1"
                                           End Function)

    Dim groupWithCalendarAdded = DataManager.CalendarGroups.FirstOrDefault(Function(cg)
                                                                             Return cg.Calendars.Contains(cal)
                                                                           End Function)


    If IsNothing(groupWithCalendarAdded) Then
      Dim newGroup = New Infragistics.Controls.Schedules.CalendarGroup
      newGroup.Calendars.Add(cal)
      Me.DataManager.CalendarGroups.Add(newGroup)
    Else


    End If

    res = DataManager.ResourceItems.GetResourceFromId("Res2")
    cal = res.Calendars.FirstOrDefault(Function(c)
                                         Return c.Id = "Cal2"
                                       End Function)

    groupWithCalendarAdded = DataManager.CalendarGroups.FirstOrDefault(Function(cg)
                                                                         Return cg.Calendars.Contains(cal)
                                                                       End Function)

    '---> den kalender der angelegten Gruppe hinzufügen
    Me.DataManager.CalendarGroups(0).Calendars.Add(cal)

  End Sub

End Class


